@@ -22,6 +22,7 @@ DEFAULT_STREAM_FORMAT = "h264"
 DEFAULT_RTMP_AUTH_METHOD = 'PASSWORD'
 
 _LOGGER = logging.getLogger(__name__)
+_LOGGER_DATA = logging.getLogger(__name__+".data")
 
 
 ref_sw_version_3_0_0_0_0 = SoftwareVersion("v3.0.0.0_0")
@@ -333,13 +334,10 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
                 "action": 1,
                 "param": {"Alarm": {"channel": self._channel, "type": "md"}},
             },
+            {"cmd": "GetPushV20", "action": 1, "param": {"channel": self._channel}},
+            {"cmd": "GetPush", "action": 1, "param": {"channel": self._channel}},
         ]
 
-        if self._sw_version_object is not None and self._sw_version_object > ref_sw_version_3_0_0_0_0:
-            body.append({"cmd": "GetPushV20", "action": 1, "param": {"channel": self._channel}})
-        else:
-            body.append({"cmd": "GetPush", "action": 1, "param": {"channel": self._channel}})
-
         if cmd_list is not None:
             for x, line in enumerate(body):
                 if line["cmd"] not in cmd_list:
@@ -485,6 +483,10 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
 
     async def map_json_response(self, json_data):  # pylint: disable=too-many-branches
         """Map the JSON objects to internal objects and store for later use."""
+
+        push_data = None
+        pushv20_data = None
+
         for data in json_data:
             try:
                 if data["code"] == 1:  # -->Error, like "ability error"
@@ -530,12 +532,10 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
                     self._ftp_state = data["value"]["Ftp"]["schedule"]["enable"] == 1
 
                 elif data["cmd"] == "GetPush":
-                    self._push_settings = data
-                    self._push_state = data["value"]["Push"]["schedule"]["enable"] == 1
+                    push_data = data
 
                 elif data["cmd"] == "GetPushV20":
-                    self._push_settings = data
-                    self._push_state = data["value"]["Push"]["enable"] == 1
+                    pushv20_data = data
 
                 elif data["cmd"] == "GetEnc":
                     self._enc_settings = data
@@ -583,6 +583,13 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
                 _LOGGER.error(traceback.format_exc())
                 continue
 
+        if pushv20_data is not None:
+            self._push_settings = pushv20_data
+            self._push_state = pushv20_data["value"]["Push"]["enable"] == 1
+        elif push_data is not None:
+            self._push_settings = push_data
+            self._push_state = push_data["value"]["Push"]["schedule"]["enable"] == 1
+
     async def login(self):
         """Login and store the session ."""
         if self.session_active:
@@ -1032,13 +1039,22 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
             if body is None:
                 async with aiohttp.ClientSession(timeout=self._timeout) as session:
                     async with session.get(url=self._url, params=param) as response:
-                        return await response.read()
+                        _LOGGER.debug("send()= HTTP Request params =%s", str(param).replace(self._password, "<password>"))
+                        json_data = await response.read()
+                        _LOGGER.debug("send HTTP Response status=%s", str(response.status))
+                        _LOGGER_DATA.debug("send() HTTP Response data: %s", str(json_data))
+
+                        return json_data
             else:
                 async with aiohttp.ClientSession(timeout=self._timeout) as session:
                     async with session.post(
                         url=self._url, json=body, params=param
                     ) as response:
+                        _LOGGER.debug("send() HTTP Request params =%s", str(param).replace(self._password, "<password>"))
+                        _LOGGER.debug("send() HTTP Request body =%s", str(body).replace(self._password, "<password>"))
                         json_data = await response.text()
+                        _LOGGER.debug("send() HTTP Response status=%s", str(response.status))
+                        _LOGGER_DATA.debug("send() HTTP Response data: %s", str(json_data))
                         return json_data
 
         except aiohttp.ClientConnectorError as conn_err:
